"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const seaFetch_1 = __importDefault(require("./seaFetch"));
const logging_1 = require("../logging");
const errors_1 = require("../model/errors");
class Identify {
    constructor(configuration) {
        this.url = `${configuration.values().identifyEndpoint}/identity/token`;
        this.apiKey = configuration.apiKey;
        this.accessToken = configuration.accessToken;
        this.autoRenew = configuration.autoRenew;
    }
    setUrl(url) {
        this.url = url;
    }
    setToken(accessToken) {
        this.autoRenew = false;
        this.accessToken = accessToken;
    }
    getToken() {
        return __awaiter(this, void 0, void 0, function* () {
            logging_1.log.info('Requestiong access token...');
            const json = {};
            const token = this.apiKey || '';
            const response = yield (0, seaFetch_1.default)(token).post(this.url, JSON.stringify(json));
            if (response.ok) {
                const body = yield response.json();
                this.accessToken = body.token;
                return body.token;
            }
            else {
                const errorBody = yield response.text();
                if (!this.apiKey) {
                    logging_1.log.error('API KEY not set, use sea.config.setApiKey');
                }
                else {
                    this.accessToken = undefined;
                    logging_1.log.error(`Request access token exception with code ${response.status}, error ${errorBody}`);
                }
                throw new errors_1.HTTPError(response.status, errorBody);
            }
        });
    }
    renewToken() {
        return __awaiter(this, void 0, void 0, function* () {
            this.accessToken = yield this.getToken();
            return this.accessToken;
        });
    }
}
exports.default = Identify;
