"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const request_1 = __importDefault(require("./request"));
const seaFetch_1 = __importDefault(require("./seaFetch"));
const metadata_1 = require("../model/metadata");
const base64_1 = require("../utils/base64");
class Metadata {
    constructor(configuration) {
        this.url = `${configuration.values().coordinationEndpoint}/config`;
        this.request = new request_1.default(configuration.identify);
    }
    set(keyValue) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.url}/base64:${(0, base64_1.encode)(keyValue.key)}`;
            const data = (0, base64_1.encode)(keyValue.value);
            const result = yield this.request.send((token) => (0, seaFetch_1.default)(token).put(url, data));
            return result === 'Ok';
        });
    }
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.url}/base64:${(0, base64_1.encode)(key.key)}`;
            const result = yield this.request.send((token) => (0, seaFetch_1.default)(token).get(url));
            return (0, metadata_1.mapToKeyValue)(result);
        });
    }
    delete(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.url}/base64:${(0, base64_1.encode)(key.key)}`;
            const result = yield this.request.send((token) => (0, seaFetch_1.default)(token).delete(url));
            return result === 'Ok';
        });
    }
    getPage(options) {
        return __awaiter(this, void 0, void 0, function* () {
            let url = this.url;
            if (options === null || options === void 0 ? void 0 : options.directory) {
                url = `${this.url}/base64:${(0, base64_1.encode)(options.directory.key)}/`;
            }
            let params = {};
            if (options === null || options === void 0 ? void 0 : options.nextKey) {
                params = {
                    from: `base64:${(0, base64_1.encode)(options.nextKey.key)}`,
                };
            }
            const result = yield this.request.send((token) => (0, seaFetch_1.default)(token).get(`${url}?` + new URLSearchParams(params)));
            return (0, metadata_1.mapToKeyValuePage)(result);
        });
    }
    getAllPages(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const pages = [];
            let forNextKey = options === null || options === void 0 ? void 0 : options.nextKey;
            while (true) {
                const pageResult = yield this.getPage({
                    directory: options === null || options === void 0 ? void 0 : options.directory,
                    nextKey: forNextKey,
                });
                const page = pageResult;
                pages.push(...page.keyValuePairs);
                if (page.nextKey) {
                    forNextKey = page.nextKey;
                }
                else {
                    return pages;
                }
            }
        });
    }
}
exports.default = Metadata;
