"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logging_1 = require("../logging");
const errors_1 = require("../model/errors");
class Request {
    constructor(identify) {
        this.identify = identify;
    }
    renewIfFails(error, bodyError, request) {
        return __awaiter(this, void 0, void 0, function* () {
            const httpError = new errors_1.HTTPError(error.status, bodyError);
            if (error.status != 401 || !this.identify.autoRenew) {
                throw httpError;
            }
            logging_1.log.info('Auto-Renew, renewing the token...');
            const token = yield this.identify.renewToken();
            return yield request(token);
        });
    }
    send(request) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            // eslint-disable-line
            const accessToken = this.identify.accessToken || (yield this.identify.getToken());
            const response = yield request(accessToken);
            const bodyText = yield response.text();
            if (response.ok) {
                return (_a = this.parse(bodyText)) !== null && _a !== void 0 ? _a : bodyText;
            }
            else {
                logging_1.log.error(`Request error: ${bodyText}`);
                return yield this.renewIfFails(response, bodyText, request);
            }
        });
    }
    parse(body) {
        // eslint-disable-line
        try {
            return JSON.parse(body);
        }
        catch (e) {
            return undefined;
        }
    }
}
exports.default = Request;
