"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const request_1 = __importDefault(require("./request"));
const base64_1 = require("../utils/base64");
const restrictions_1 = require("../model/restrictions");
const errors_1 = require("../model/errors");
const seaFetch_1 = __importDefault(require("./seaFetch"));
class Restrictions {
    constructor(configuration) {
        this.url = `${configuration.values().coordinationEndpoint}/restrict`;
        this.request = new request_1.default(configuration.identify);
    }
    get(api, key) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.url}/${api}/base64:${(0, base64_1.encode)(key.key)}/`;
            const result = yield this.request.send((token) => (0, seaFetch_1.default)(token).get(url));
            return (0, restrictions_1.mapToRestriction)(result);
        });
    }
    set(api, key, restrictionDetails) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.url}/${api}/base64:${(0, base64_1.encode)(key.key)}/`;
            const data = {
                regions_allowed: restrictionDetails.regionsAllowed.map((region) => region),
                regions_denied: restrictionDetails.regionsDenied.map((region) => region),
                providers_allowed: restrictionDetails.providersAllowed.map((provider) => provider),
                providers_denied: restrictionDetails.providersDenied.map((provider) => provider),
            };
            const result = yield this.request.send((token) => (0, seaFetch_1.default)(token).put(url, JSON.stringify(data)));
            return result == 'Ok';
        });
    }
    delete(api, key) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.url}/${api}/base64:${(0, base64_1.encode)(key.key)}/`;
            const result = yield this.request.send((token) => (0, seaFetch_1.default)(token).delete(url));
            return result === 'Ok';
        });
    }
    getPage(options) {
        return __awaiter(this, void 0, void 0, function* () {
            let url = this.url;
            if ((options === null || options === void 0 ? void 0 : options.api) && !(options === null || options === void 0 ? void 0 : options.isAllRange)) {
                url = `${url}/${options.api}`;
            }
            let params = {};
            if (options === null || options === void 0 ? void 0 : options.fromRestriction) {
                if (!(options === null || options === void 0 ? void 0 : options.api)) {
                    throw new errors_1.SeaplaneError("You must set 'api' with 'fromRestriction' parameters.");
                }
                params = {
                    from: `base64:${(0, base64_1.encode)(options.fromRestriction.key)}`,
                    from_api: String(options.api),
                };
            }
            const result = yield this.request.send((token) => (0, seaFetch_1.default)(token).get(`${url}?` + new URLSearchParams(params)));
            return (0, restrictions_1.mapToRestrictionPage)(result);
        });
    }
    getAllPages(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const pages = [];
            let forNextRestriction = options === null || options === void 0 ? void 0 : options.fromRestriction;
            let fromApi = options === null || options === void 0 ? void 0 : options.api;
            while (true) {
                const pageResult = yield this.getPage({
                    api: fromApi,
                    fromRestriction: forNextRestriction,
                    isAllRange: true,
                });
                const page = pageResult;
                pages.push(...page.restrictions);
                if (page.nextKey && page.nextApi) {
                    forNextRestriction = page.nextKey;
                    fromApi = page.nextApi;
                }
                else {
                    return pages;
                }
            }
        });
    }
}
exports.default = Restrictions;
