"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapToRestrictionPage = exports.mapToRestriction = exports.RestrictionState = exports.SeaplaneApi = void 0;
const provider_1 = require("./provider");
const region_1 = require("./region");
const metadata_1 = require("./metadata");
const errors_1 = require("./errors");
var SeaplaneApi;
(function (SeaplaneApi) {
    SeaplaneApi["Locks"] = "locks";
    SeaplaneApi["Metadata"] = "config";
})(SeaplaneApi = exports.SeaplaneApi || (exports.SeaplaneApi = {}));
var RestrictionState;
(function (RestrictionState) {
    RestrictionState["Enforced"] = "Enforced";
    RestrictionState["Pending"] = "Pending";
})(RestrictionState = exports.RestrictionState || (exports.RestrictionState = {}));
const mapToRestriction = (restrictionBody) => {
    const restriction = restrictionBody;
    const key = (0, metadata_1.mapKey)(restriction['directory']);
    if (key == null) {
        throw new errors_1.SeaplaneError('Directory must not be null');
    }
    return {
        api: seaplaneApi(restriction['api']),
        directory: key,
        details: mapToRestrictionDetails(restriction),
        state: mapState(restriction['state']),
    };
};
exports.mapToRestriction = mapToRestriction;
const mapToRestrictionDetails = (restriction) => ({
    regionsAllowed: (0, region_1.mapToRegions)(restriction['details']['regions_allowed']),
    regionsDenied: (0, region_1.mapToRegions)(restriction['details']['regions_denied']),
    providersAllowed: (0, provider_1.mapToProvider)(restriction['details']['providers_allowed']),
    providersDenied: (0, provider_1.mapToProvider)(restriction['details']['providers_denied']),
});
const mapToSeaplaneApi = (api) => {
    if (!api) {
        return null;
    }
    return seaplaneApi(api);
};
const mapToRestrictionPage = (restrictionPage) => ({
    restrictions: restrictionPage['restrictions'].map(exports.mapToRestriction),
    nextApi: mapToSeaplaneApi(restrictionPage['next_api']),
    nextKey: (0, metadata_1.mapKey)(restrictionPage['next_key']),
});
exports.mapToRestrictionPage = mapToRestrictionPage;
const capitalize = (string) => string.charAt(0).toUpperCase() + string.slice(1);
const seaplaneApi = (api) => (api == 'config' ? SeaplaneApi.Metadata : SeaplaneApi.Locks);
const mapState = (state) => state == 'enforced' ? RestrictionState.Enforced : RestrictionState.Pending;
