import seaFetch from './seaFetch';
import { log } from '../logging';
import { HTTPError } from '../model/errors';
export default class Identify {
    url;
    accessToken;
    apiKey;
    autoRenew;
    constructor(configuration) {
        this.url = `${configuration.values().identifyEndpoint}/identity/token`;
        this.apiKey = configuration.apiKey;
        this.accessToken = configuration.accessToken;
        this.autoRenew = configuration.autoRenew;
    }
    setUrl(url) {
        this.url = url;
    }
    setToken(accessToken) {
        this.autoRenew = false;
        this.accessToken = accessToken;
    }
    async getToken() {
        log.info('Requestiong access token...');
        const json = {};
        const token = this.apiKey || '';
        const response = await seaFetch(token).post(this.url, JSON.stringify(json));
        if (response.ok) {
            const body = await response.json();
            this.accessToken = body.token;
            return body.token;
        }
        else {
            const errorBody = await response.text();
            if (!this.apiKey) {
                log.error('API KEY not set, use sea.config.setApiKey');
            }
            else {
                this.accessToken = undefined;
                log.error(`Request access token exception with code ${response.status}, error ${errorBody}`);
            }
            throw new HTTPError(response.status, errorBody);
        }
    }
    async renewToken() {
        this.accessToken = await this.getToken();
        return this.accessToken;
    }
}
