import { mapToProvider } from './provider';
import { mapToRegions } from './region';
import { mapKey } from './metadata';
import { SeaplaneError } from './errors';
export var SeaplaneApi;
(function (SeaplaneApi) {
    SeaplaneApi["Locks"] = "locks";
    SeaplaneApi["Metadata"] = "config";
})(SeaplaneApi || (SeaplaneApi = {}));
export var RestrictionState;
(function (RestrictionState) {
    RestrictionState["Enforced"] = "Enforced";
    RestrictionState["Pending"] = "Pending";
})(RestrictionState || (RestrictionState = {}));
export const mapToRestriction = (restrictionBody) => {
    const restriction = restrictionBody;
    const key = mapKey(restriction['directory']);
    if (key == null) {
        throw new SeaplaneError('Directory must not be null');
    }
    return {
        api: seaplaneApi(restriction['api']),
        directory: key,
        details: mapToRestrictionDetails(restriction),
        state: mapState(restriction['state']),
    };
};
const mapToRestrictionDetails = (restriction) => ({
    regionsAllowed: mapToRegions(restriction['details']['regions_allowed']),
    regionsDenied: mapToRegions(restriction['details']['regions_denied']),
    providersAllowed: mapToProvider(restriction['details']['providers_allowed']),
    providersDenied: mapToProvider(restriction['details']['providers_denied']),
});
const mapToSeaplaneApi = (api) => {
    if (!api) {
        return null;
    }
    return seaplaneApi(api);
};
export const mapToRestrictionPage = (restrictionPage) => ({
    restrictions: restrictionPage['restrictions'].map(mapToRestriction),
    nextApi: mapToSeaplaneApi(restrictionPage['next_api']),
    nextKey: mapKey(restrictionPage['next_key']),
});
const capitalize = (string) => string.charAt(0).toUpperCase() + string.slice(1);
const seaplaneApi = (api) => (api == 'config' ? SeaplaneApi.Metadata : SeaplaneApi.Locks);
const mapState = (state) => state == 'enforced' ? RestrictionState.Enforced : RestrictionState.Pending;
